Composition root: probes the server, selects the store and engine implementations, and publishes the in-process client.
Structs
- Graph
Storage - The graph-storage gear.
Composition root: probes the server, selects the store and engine implementations, and publishes the in-process client.